import requests
import json
import sys
from requests.exceptions import ConnectionError

BASE_URI = 'http://127.0.0.1:9099'

try:
    status = requests.get('{}/get-status'.format(BASE_URI))
    status.raise_for_status()

    if status.json() == 'off':
        requests.get('{}/change-status'.format(BASE_URI))

    response = requests.get('{}/all'.format(BASE_URI))
    rules = response.json()

    if rules is None:
        print('No rules defined, skipping..')
        sys.exit()

    has_api_port = any(rule for rule in rules if rule['dstport'] == '3001')

    if has_api_port:
        print(':3001 port is already reachable, skipping..')
        sys.exit()

    response = requests.post('{}/add'.format(BASE_URI), data=json.dumps({
        "target": "ACCEPT",
        "protocol": "tcp",
        "iin": "*",
        "iout": "*",
        "src": "tbox",
        "dst": "0.0.0.0/0",
        "srcport": "",
        "dstport": "3001"
    }))

    if response.status_code == 200:
        print("port successfully added")
        print("persisting rules..")
        requests.get('{}/save'.format(BASE_URI))
        requests.get('{}/change-status'.format(BASE_URI))
        requests.get('{}/change-status'.format(BASE_URI))

        print('done')

except ConnectionError:
    print('is tbox-net-firewall installed?')
except Exception as e:
    print(e)
