import { FileDto } from "../dto/file.dto";
import debug from 'debug';
import fs from 'fs';
import util from 'util';
import multer from 'multer';
import path from 'path';

const log: debug.IDebugger = debug('app:in-memory-dao');
class FilesDao {
    files: Array<FileDto> = [];
    mainFolder = '../apks/';
    readdir = util.promisify(fs.readdir);

    constructor() {
        log('Created new instance of FilesDao');
    }

    async getFiles() {
        const files = await this.readdir(this.mainFolder);
        this.files = files.map(file => ({ name: file, size: fs.statSync(path.join(this.mainFolder, file)).size }));
        return this.files;
    }


    removeFileByName = async (name: string) => {
        const fileMatched = (await this.getFiles()).find(file => file.name == name);

        if (!fileMatched) {
            throw new Error("File not found");
        }
        
        try {
            fs.unlinkSync(path.join(this.mainFolder, fileMatched.name));
        } catch (error) {
            throw new Error("Could not remove file");
        }
        return `${name} removed`;
    }

}

export default new FilesDao();