import { CommonRoutesConfig } from '../common/common.routes.config';
import FilesController from './controllers/files.controller';
import FilesMiddleware from './middleware/files.middleware';
import express from 'express';

export class FilesRoutes extends CommonRoutesConfig {
    constructor(app: express.Application) {
        super(app, 'FilesRoutes');
    }

    configureRoutes() {
        this.app.route(`/files`)
            .get(FilesController.listFiles)
            .post(FilesMiddleware.uploadSingleFile().single('file'), FilesController.createFile);
        
        this.app.param(`filename`, FilesMiddleware.extractFileId);
        
        this.app.route(`/files/:filename`)
            .delete(FilesController.removeFile);

        return this.app;
    }
}