import express from 'express';
import fileService from '../services/files.service';
import debug from 'debug';
import multer from 'multer';
import fs from 'fs'

const log: debug.IDebugger = debug('app:files-controller');
class FilesMiddleware {

    async validateRequiredFileBodyFields(req: express.Request, res: express.Response, next: express.NextFunction) {
        if (req.body && req.body.email && req.body.password) {
            next();
        } else {
            res.status(400).send({ error: `Missing required fields email and password` });
        }
    }

    uploadSingleFile() {
        var storage = multer.diskStorage({
            destination: function (req, file, cb) {
                const { destination } = req.body
                const path = `../apks/${destination}`
                fs.mkdirSync(path, { recursive: true })
                cb(null, path);
            },
            filename: function (req, file, cb) {
                cb(null, file.originalname);
            }
        });

        return multer({ storage });
    }

    async validateFileExists(req: express.Request, res: express.Response, next: express.NextFunction) {
        const file = await fileService.readById(req.params.userId);
        if (file) {
            next();
        } else {
            res.status(404).send({ error: `User ${req.params.userId} not found` });
        }
    }

    async extractFileId(req: express.Request, res: express.Response, next: express.NextFunction) {
        req.body.id = req.params.userId;
        next();
    }
}

export default new FilesMiddleware();