var providers;
var providerDomain;

function setProviders(_providers) {
    providers = _providers;
}

function getProviders() {
    return providers;
}

function setProviderDomain(_providerDomain) {
    providerDomain = _providerDomain;
}

function getProviderDomain() {
    return providerDomain;
}

function getErrorMessage(e) {
    let html = '';
    html += `<div style="padding: 10px; color: #ccc;">`;
    html += `<h2>The follow error was found</h2>`;
    html += `<p>${e}</p>`
    html += `</div>`;
    return html;
}

$('document').ready(function () {
    initMain().then(function () {
        initLogin();
        $("body").show();
    })
    .catch(function (e) {
        $("body").show().append(getErrorMessage(`\nError: ${e.error} file: ${e.file}`));
    });
});

function initTypeHead() {
    new autoComplete({
        selector: '#providers',
        minChars: 3,
        source: function (term, suggest) {
            term = term.toLowerCase();
            var choices = getProviders();
            var suggestions = [];
            for (i = 0; i < choices.length; i++)
                if (~(choices[i][0] + ' ' + choices[i][1]).toLowerCase().indexOf(term)) suggestions.push(choices[i]);
            suggest(suggestions);
        },

        renderItem: function (item, search) {
            search = search;
            var re = new RegExp("(" + search.split(' ').join('|') + ")", "gi");
            return '<div class="autocomplete-suggestion" data-name="' + item[0] + '" data-provider="' + item[1] + '" data-val="' + search + '"> '
                + item[0].replace(re, "<b>$1</b>") + ' (' + item[1] + ')' + '</div>';
        },
        onSelect: function (e, term, item) {
            document.getElementById('providers').value = item.getAttribute('data-provider');
        }
    });

    $('#providers').keydown(function (event) {
        if (event.keyCode == 13) {
            event.preventDefault();
            return false;
        }
    });
}

function getIPLocation(ip) {
    console.log("getIPLocation")
    fetch('http://ip-api.com/json/' + ip)
        .then(response => {
            try {
                return response.json()
            } catch (e) {
                console.log(e)
            }
        })
        .then(data => {
            try {
                Cookies.set('lat', data.lat);
                Cookies.set('lon', data.lon);
            } catch (e) {
                console.log(e)
            }
        })
        .catch(err => {
            console.log(err);
            // Do something for an error here
        })
}

function getMyIP() {
    fetch('https://ip.seeip.org/json')
        .then(response => {
            try {
                return response.json()
            } catch (e) {
                console.log(e)
            }
        })
        .then(data => {
            try {
                this.getIPLocation(data.ip);
            } catch (e) {
                console.log(e)
            }
        })
        .catch(err => {
            console.log(err)
        })

}

function initLogin() {
    this.getMyIP();
    importCssFile('assets/css/login.css');

    initHeader();
    initLoginTemplate();
    initStillWatchingModal();

    var data;
    var rtoken = Cookies.get('rtoken');
    var last_access = Cookies.get('last_access');

    if (isDemo()) {
        var demo_user = 'cdntv';
        var demo_pwd = 'cdntv';

        if (!last_access) {
            data = JSON.stringify({ "username": demo_user, "password": demo_pwd });
            makeLogin(data)
                .then(
                    function (data) {
                        changePage('/');
                    }
                ).catch(
                    function (error) {
                        showLogin();
                    }
                );
        } else {
            showLogin();
        }
    } else if (rtoken) {
        data = JSON.stringify({ "token": rtoken });
        makeLogin(data)
            .then(
                function (data) {
                    changePage('/');
                }
            ).catch(
                function (error) {
                    showLogin();
                }
            );
    } else {
        showLogin();
    }
}

var getJSON = function (url, callback) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, true);
    xhr.responseType = 'json';
    xhr.onload = function () {
        var status = xhr.status;
        if (status === 200) {
            callback(null, xhr.response);
        } else {
            callback(status, xhr.response);
        }
    };
    xhr.send();
};

function initLoginTemplate() {

    if (getProvidersList()) {
        console.log(getProvidersList());
        getJSON(getProvidersList(),
            function (err, data) {
                if (err !== null) {
                    alert('Error: ' + err);
                } else {
                    var providersBox =
                        '<div class="modal-group">' +
                        '<select class="modal-input" name="providers" id="providers" required>'
                    for (var i = 0; i < data.length; i++) {
                        providersBox += '<option value="' + data[i].edge + '">' + data[i].name + '</option>'
                    }
                    providersBox +=
                        '</select>' +
                        '</div>'

                    buildLoginTemplate(providersBox);
                }
            });

    } else {
        buildLoginTemplate('');
    }
}

function buildLoginTemplate(providersField) {
    var expired = Cookies.get('expired');
    Cookies.remove('expired');
    var expiredMsg = '';

    if (expired === "true") {
        if (isDemo()) {
            expiredMsg = 'Período de demonstração expirado!';
        } else {
            expiredMsg = 'Sessão expirada!';
        }
    }

    var template;
    template =
        '<div class="modal-animate">' +
        '<form class="modal-content" onsubmit="loginSubmit(); return false;">' +

        '<div class="modal-group">' +
        '<p class="expired-session" id="expired-session">' + expiredMsg + '</p>' +
        '</div>' +

        providersField +

        '<div class="modal-group">' +
        '<input class="modal-input" type="text" name="user" id="user" required>' +
        '<p class="modal-input-label">Usuário</p>' +
        '</div>' +

        '<div class="modal-group">' +
        '<input class="modal-input" type="password" name="pwd" id="pwd" required>' +
        '<p class="modal-input-label">Senha</p>' +
        '</div>' +

        '<div class="modal-group">' +
        '<button class="modal-button modal-button-positive" type="submit">Entrar</button>' +
        '</div>' +

        '<div class="modal-group" style="display: none;">' +
        '<div class="login-result" id="login-result"><i class="fas fa-spinner fa-spin"></i></div>' +
        '</div>' +

        '</form>' +
        '</div>';

    $('#login-modal').html(template);
}

function loginSubmit() {
    var user = document.getElementsByName("user")[0].value;
    var pwd = document.getElementsByName("pwd")[0].value;
    var lat = localStorage.getItem('lat');
    var lon = localStorage.getItem('lon');

    $('#login-result').html('<i class="fas fa-spinner fa-spin"></i>');
    $('#login-result').parent().show();

    var data;
    if (getProvidersList()) {
        var provider = document.getElementsByName("providers")[0].value;
        data = JSON.stringify({ "username": user, "password": pwd, "provider": provider, "location": { "latitude": lat, "longitude": lon } });
        if (provider == null || provider.length == 0) {
            showLoginError({ "status": -1 });
            return;
        }
    } else {
        data = JSON.stringify({ "username": user, "password": pwd, "location": { "latitude": lat, "longitude": lon } });
    }

    makeLogin(data)
        .then(
            function (data) {
                changePage('/');
            }
        ).catch(
            function (error) {
                showLoginError(error);
            }
        );
}

function showLoginError(error) {
    var errorMsg;

    if (error.status === -1) {
        errorMsg = 'Selecione o provedor.';
    } else if (error.status === 0) {
        errorMsg = 'Não foi possível conectar a <a style="text-decoration: none" href="' + getManagerUrl() + '">' + getManagerUrl().split("://")[1] + '</a>! Verifique sua conexão com este domínio.';
    } else if (error.status === 401) {
        errorMsg = 'Credenciais de acesso inválidas!';
    } else if (error.status === 403) {
        errorMsg = 'Usuário bloqueado pelo sistema! Entre em contato com o provedor.';
    } else if (error.status === 429) {
        errorMsg = 'Máximo de sessões da conta foi atingido!';
    } else if (error.status >= 500 && error.status < 510) {
        errorMsg = 'Erro inesperado no servidor de autenticação!';
    } else {
        errorMsg = 'Erro inesperado no sistema (' + error.status + ')!';
    }

    setTimeout(function () {
        $('#expired-session').hide();
        $('#login-result').html('<p>' + errorMsg + '</p>');
    }, 1000);
}

function showLogin() {
    $('#login-modal').show();
    setTimeout(initLoginDataListeners, 300);
}

function hideLogin() {
    $('#login-modal').hide();
}

//Login data listeners
function initLoginDataListeners() {
    var user = document.querySelector('#user');
    var pwd = document.querySelector('#pwd');
    var providers = document.querySelector('#providers');

    if (user === null && pwd === null) {
        setTimeout(initLoginDataListeners, 300);
    } else {
        if (user.value.length >= 0) {
            user.parentElement.classList.add("modal-input-filled");
        }
        if (pwd.value.length >= 0) {
            pwd.parentElement.classList.add("modal-input-filled");
        }

        if (providers && providers !== null && providers.value.length >= 0) {
            providers.parentElement.classList.add("modal-input-filled");
        }

        user.addEventListener('focus', onUserFocus);
        user.addEventListener('blur', onUserBlur);
        pwd.addEventListener('focus', onPasswordFocus);
        pwd.addEventListener('blur', onPasswordBlur);

        if (providers && providers !== null) {
            providers.addEventListener('focus', onPasswordFocus);
            providers.addEventListener('blur', onPasswordBlur);
        }

        initTypeHead();
    }




}

function onUserFocus(e) {
    e.target.parentElement.classList.add("modal-input-filled");
}

function onUserBlur(e) {
    if (e.target.value === "") {
        e.target.parentElement.classList.remove("modal-input-filled");
    }
}

function onPasswordFocus(e) {
    e.target.parentElement.classList.add("modal-input-filled");
}

function onPasswordBlur(e) {
    if (e.target.value === "") {
        e.target.parentElement.classList.remove("modal-input-filled");
    }
}