var channels = null;
var previousChannel = null;

$('document').ready(function () {
    initMain().then(function () {
        initOldLayout();
    });
});

function initOldLayout() {
    importCssFile('assets/css/old-layout.css');
    importCssFile('theme/custom-style.css');
    initHeader();
    getLoginInfo()
        .then(
            function (data) {
                console.log('data', data)
                initOldLayoutData();
                $("body").show();
            }
        );
}

function initOldLayoutData() {
    initRenewToken();
    initLeftMenu();
    // initRightMenu();
    initStillWatchingModal();
    initRestrictModal();
    initData();
    bindEscapeKeyModal();
}

function initData() {
    refresh();
    window.onresize = resizePlayer;
}

function refresh() {
    var token = Cookies.get('token');
    var lastWatchedCh = Cookies.get('lastChannel');

    $.ajax({
        "url": getManagerUrl() + "/channels?t=" + token,
        "method": "GET",
        "headers": {
            "Accept": "application/json",
            "Content-Type": "application/json"
        },
        "dataType": "json",
        "crossDomain": true,
        success: function (data) {
            try{
                if (data.length > 0) {
                    channels = data;

                    var lastCh = getChannelById(lastWatchedCh, channels);
                    if (!lastCh) {
                        lastCh = channels[0];
                    }

                    buildChannelsList(data);
                    activateChannelsBody();

                    if (isInChannels(previousChannel, data)) {
                        if (getPlayer().isPlaying()) {
                            activateChannel(previousChannel);
                        } else {
                            switchChannel(lastCh.id);
                        }
                    } else {
                        switchChannel(lastCh.id);
                    }

                    toast("Canais carregados com sucesso!", 3);
                } else {
                    deactivateChannelsBody();
                }
            }catch(e){
                console.log(e);
                deactivateChannelsBody();
            }
        },
        error: function () {
            deactivateChannelsBody();
        }
    });
}

function initChannel(ch, stop) {
    if (ch) {
        activateChannelsBody();
        var token = Cookies.get('token');

        var options = {
            "fixed": false,
            "hideMediaControl": true,
            "plugins": ["LevelSelector"],
            "mediaControlRemove": ["seekbar", "position", "duration", "playpause", "playstop"],
            "guideParentElem": '.media-control-background'
        };
        options.poster = ch.logo;
        initPlayer(ch, "player", options);

        if (stop) {
            stopPlayer(false);
        } else {
            activateChannel(ch);
        }
        resizePlayer();
    }
}

function validateRestrictPassword(e) {
    var pass = $("#pwd-restrict").val(); 

    var parpass = Cookies.get("parpass");
    if (sha1(pass) == parpass) {
        setIsRestrict(false);
        hideRestrictModal();
        refresh();
    }

    return false;
}

function switchChannel(ch_id) {
    var ch = getChannelById(ch_id, channels);
    Cookies.set('lastChannel', ch.id);
    setLastPlayerRetry(null);
    var token = Cookies.get('token');

    if (ch.rating > 16) {
        if (isRestrict() == false){
            setIsRestrict(false);
        } else {
            setIsRestrict(true);
        }
    }

    if (ch.rating > 16 && isRestrict()) {
        stopPlayer(true);
        showRestrictModal();
    } else {
        $.ajax({
            "url": getManagerUrl() + "/channels/" + ch.id + "?t=" + token,
            "method": "GET",
            "headers": {
                "Accept": "application/json",
                "Content-Type": "application/json"
            },
            "dataType": "json",
            "crossDomain": true,
            success: function (response) {
                try{
                    if (response.health === 0) {
                        initChannel(ch, false);
                        startRecoverError(ch);
        
                    } else {
                        checkTokenExpire({});
                        initChannel(ch, false);
                    }
                }catch(e){
                    activateChannel(ch);
                    showPlayerError();
                    console.log(e);
                }
            },
            error: function () {
                activateChannel(ch);
                showPlayerError();
            }
        });
    }

}

function activateChannel(ch) {
    if (previousChannel) {
        if (document.getElementById('ch' + previousChannel.id + '-play')) {
            document.getElementById('ch' + previousChannel.id + '-play').style.display = 'none';
            document.getElementById('ch' + previousChannel.id + '-num').style.display = 'block';
            document.getElementById('ch' + previousChannel.id + '-watching').style.display = 'none';
            document.getElementById('ch' + previousChannel.id + '-watching-label').style.display = 'none';
        }
    }

    document.getElementById('ch' + ch.id + '-play').style.display = 'block';
    document.getElementById('ch' + ch.id + '-num').style.display = 'none';
    document.getElementById('ch' + ch.id + '-watching').style.display = 'block';
    document.getElementById('ch' + ch.id + '-watching-label').style.display = 'block';

    previousChannel = ch;
}

function activateChannelsBody() {
    document.getElementById('no-channels').style.display = 'none';
    document.getElementById('has-channels').style.display = 'block';
}

function deactivateChannelsBody() {
    stopPlayer(true);
    showErrorPage("no-channels");
    document.getElementById('no-channels').style.display = 'block';
    document.getElementById('has-channels').style.display = 'none';
}

function isRelative(url) {
    return url.indexOf("://") < 0;
}

function buildChannelsList(channels) {
    var template = '';
    template += '<div>';
    template += '<span class="playlist-refresh" onclick="refresh(); return false;">&#x21BB;</span>';
    template += '<div class="playlist-channels-count">';

    template += '<p>Todos os Canais (' + channels.length + ')' + '</p>';

    template += '</div>';

    template += '</div>';

    template += '<div class="playlist-scrollable">';
    template += '<div class="playlist-scroll-box">';

    for (var i = 0; i < channels.length; i++) {
        var channel = channels[i];

        if (channel.logo !== null && isRelative(channel.logo)) {
            channel.logo = getManagerUrl() + channel.logo;
        }

        template += '<a class="playlist-item" title="' + channel.name + '" onclick="switchChannel(' + channel.id + ');" href="#">';
        template += '<div class="playlist-item-index">';
        template += '<div id="ch' + channel.id + '-play" class="playing-icon" style="display: none;">&#9658;</div>';
        template += '<div id="ch' + channel.id + '-num">' + channel.number + '</div>';
        template += '</div>';
        template += '<div class="playlist-item-widget">';
        template += '<div class="playlist-item-image"></div>';
        template += '<div class="playlist-item-content">';
        template += '<div class="playlist-item-logo">';
        template += '<img src="' + channel.logo + '"/>';
        template += '</div>';
        template += '<div id="ch' + channel.id + '-watching" class="playlist-item-watching-cover" style="display: none"></div>';
        template += '<div id="ch' + channel.id + '-watching-label" class="playlist-item-watching-label " style="display: none">Assistindo</div>';
        template += '</div>';
        template += '</div>';
        template += '<span>';
        template += '<div class="playlist-item-title">' + channel.name + '</div>';
        template += '</span>';
        template += '</a>';
    }

    template += '</div>';
    template += '</div>';

    $("#channels").html(template);
}

function getChannelById(ch_id, ch_arr) {
    if (ch_id) {
        for (var i = 0; i < ch_arr.length; i++) {
            if (ch_arr[i].id === parseInt(ch_id)) {
                return ch_arr[i];
            }
        }
    }
    return null;
}

function isInChannels(ch, ch_arr) {
    if (ch) {
        for (var i = 0; i < ch_arr.length; i++) {
            if (ch_arr[i].id === ch.id) {
                return true;
            }
        }
    }
    return false;
}

function isRadio(ch) {
    if (ch.name.indexOf("Rádio") >= 0) {
        return true;
    } else {
        return false;
    }
}

function bindEscapeKeyModal() {
    $(document).keyup(function(e) {
        if (e.keyCode === 27){
            if($('#restrict-modal').css('display') !== 'none') {
                hideRestrictModal();
            } 
        }
    });
}