/*VARIABLES*/
var playerObj;
var playerElem;
var playerOptions;
var channelObj;
var lastPlayerRetry = null;
var recoverErrorChannel = null;

/*SETTERS AND GETTERS*/
function setPlayer(_player, _elemId) {
    playerObj = _player;
    playerElem = document.getElementById(_elemId);
}

function getPlayer() {
    return playerObj;
}

function getPlayerElem() {
    return playerElem;
}

function setPlayerOptions(_options) {
    playerOptions = _options;
}

function getPlayerOptions() {
    return playerOptions;
}

function setLastPlayerRetry(time) {
    lastPlayerRetry = time;
}

function getLastPlayerRetry() {
    return lastPlayerRetry;
}

function setChannelObj(_ch) {
    channelObj = _ch;
}

function getChannelObj() {
    return channelObj;
}

function getRecoverErrorChannel() {
    return recoverErrorChannel;
}

function startRecoverError(ch) {
    recoverErrorChannel = ch;
    recoverError();
}

$('document').ready(function () {
    importCssFile('assets/css/player.css');
    importJsFile('assets/js/player-guide.js');
});

/*MAIN FUNCTIONS*/
function initPlayer(ch, elemId, options) {
    setChannelObj(ch);
    setPlayerOptions(options);

    if (getPlayer()) {
        refreshPlayer();
    } else {
        initPlayerObject(elemId);
    }

    checkTokenExpire(options);
}

function initPlayerObject(elemId) {
    var ch = getChannelObj();
    var options = getPlayerOptions();
    var token = Cookies.get('token');

    var fixed = typeof options.fixed !== 'undefined' ? options.fixed : false;
    var autoplay = typeof options.autoplay !== 'undefined' ? options.autoplay : true;
    var hideMediaControl = typeof options.hideMediaControl !== 'undefined' ? options.hideMediaControl : true;
    var hideErrors = typeof options.hideErrors !== 'undefined' ? options.hideErrors : false;
    var mute = typeof options.mute !== 'undefined' ? options.mute : false;
    var guideElem = typeof options.guideParentElem !== 'undefined' ? options.guideParentElem : false;
    var chromecast = {};
    var poster = typeof ch.poster !== 'undefined' ? ch.poster : options.poster;
    var aonly = typeof ch.aonly !== 'undefined' ? ch.aonly : options.aonly;
    

    var plugins = [];
    if (typeof options.plugins !== 'undefined') {
        for (var i = 0; i < options.plugins.length; i++) {
            if (options.plugins[i] === "LevelSelector") {
                plugins.push(LevelSelector);
            } else if (options.plugins[i] === "ChromecastPlugin") {
                plugins.push(ChromecastPlugin);
                chromecast = {
                    appId: "CC1AD845", //use default receiver
                    media: {
                        title: ch.name
                    }
                };
            }
        }
    }

    var mediaControlRemove = [];
    if (typeof options.mediaControlRemove !== 'undefined') {
        mediaControlRemove = options.mediaControlRemove;
    }
    setCustomMediaControl(mediaControlRemove);

    var p = new Clappr.Player({
        source: getManagerUrl() + ch.hls + '&t=' + token,
        chromeless: false,
        parentId: "#" + elemId,
        width: "100%",
        height: "100%",
        autoPlay: autoplay,
        hideMediaControl: hideMediaControl,
        mediacontrol: {external: TboxMediaControl},
        mute: mute,
        poster: aonly ? poster : "",
        plugins: {
            'core': plugins
        },

        chromecast: chromecast,

        language: 'pt-BR',
        strings: {
            'pt-BR': {
                'live': 'Ao Vivo',
                'back_to_live': 'Voltar para o Ao Vivo',
                'disabled': 'Desativado',
                'playback_not_supported': 'Este navegador ou dispositivo não suportam a reprodução deste vídeo.'
            }
        }
    });
    p.play();
    setPlayer(p, elemId, options);
    checkTokenExpire(options);
    initPlayerOverlay(options);

    if (hideErrors) {
        hidePlayerErrors();
    } else {
        initPlayerErrorHandler(ch);
    }

    if (!fixed) {
        window.onresize = resizePlayer;
        resizePlayer();
    } else {
        window.onresize = null;
    }
}

function initPlayerOverlay(options) {
    var guideElem = typeof options.guideParentElem !== 'undefined' ? options.guideParentElem : false;
    var overlayElem = typeof options.overlayElem !== 'undefined' ? options.overlayElem : false;

    initGuide(guideElem, options);

    if (guideElem) {
        getPlayer().listenTo(getPlayer().core.getCurrentContainer(),
            Clappr.Events.CONTAINER_MEDIACONTROL_SHOW,
            function () {
                $('.media-control-background').css("opacity", "1");
                //updateGuide(guideElem);
            }
        );

        getPlayer().listenTo(getPlayer().core.getCurrentContainer(),
            Clappr.Events.CONTAINER_MEDIACONTROL_HIDE,
            function () {
                $('.media-control-background').css("opacity", "0");
                $(overlayElem).css("opacity", "0");
            }
        );
    }

    if (overlayElem) {
        var playerElem = "#" + getPlayerElem().id;

        $(playerElem).mouseenter(function () {
            $(overlayElem).css("opacity", "1");
        });

        $(overlayElem).mouseenter(function () {
            $(overlayElem).css("opacity", "1");
            $('.media-control-background').css("opacity", "1");
        });

        $(playerElem).mouseleave(function () {
            $(overlayElem).css("opacity", "0");
        });

        $(overlayElem).mouseleave(function () {
            $(overlayElem).css("opacity", "0");
            $('.media-control-background').css("opacity", "0");
        });
    }
}

function refreshPlayer() {
    var token = Cookies.get('token');
    var options = getPlayerOptions();

    var guideElem = typeof options.guideParentElem !== 'undefined' ? options.guideParentElem : false;
    var hideErrors = typeof options.hideErrors !== 'undefined' ? options.hideErrors : false;
    var fixed = typeof options.fixed !== 'undefined' ? options.fixed : false;
    var poster = typeof getChannelObj().poster !== 'undefined' ? getChannelObj().poster : options.poster;
    var aonly = typeof getChannelObj().aonly !== 'undefined' ? getChannelObj().aonly : false;

    getPlayer().configure({
        source: getManagerUrl() + getChannelObj().hls + '&t=' + token,
        chromeless: false,
        poster: aonly ? poster : ""
    });
    getPlayer().play();
    checkTokenExpire(options);
    initPlayerOverlay(options);

    if (hideErrors) {
        hidePlayerErrors();
    } else {
        initPlayerErrorHandler(getChannelObj());
    }

    if (!fixed) {
        window.onresize = resizePlayer;
        resizePlayer();
    } else {
        window.onresize = null;
    }
}

function startPlayer() {
    if (getPlayer()) {
        getPlayer().play();
    }
}

function retryConnection() {
    if (!getPlayer().isPlaying()) {
        startPlayer();
    }
}

function stopPlayer(can_play) {
    if (getPlayer()) {
        getPlayer().stop();
    }
    if (!can_play) {
        hidePlayButton();
    }
}

function resizePlayer() {
    var aspectRatio = 9 / 16;
    var playerElem = getPlayerElem();
    var player = getPlayer();
    if (playerElem && player) {
        var newWidth = playerElem.parentElement.offsetWidth;
        var newHeight = 2 * Math.round(newWidth * aspectRatio / 2);
        player.resize({width: newWidth, height: newHeight});

        setTimeout(
            function () {
                newWidth = playerElem.parentElement.offsetWidth;
                newHeight = 2 * Math.round(newWidth * aspectRatio / 2);
                player.resize({width: newWidth, height: newHeight});
            }, 500
        );
    }
}

function hidePlayButton() {
    $('.spinner-three-bounce').hide();
    $('.play-wrapper').hide();
    getPlayer().configure({
        chromeless: true,
        allowUserInteraction: false
    });
}

function hidePlayerErrors() {
    addCssRule(".player-error-screen", "display: none !important;");
}

/*ERROR HANDLERS*/
function initPlayerErrorHandler(ch) {
    getPlayer().on(Clappr.Events.PLAYER_ERROR, function () {
        startRecoverError(ch);
    });
}

function recoverError() {
    var now = new Date();

    //Retry play on same channel for one minute
    if (getChannelObj().id === getRecoverErrorChannel().id) {
        showPlayerError();

        if (!getLastPlayerRetry()) {
            stopPlayer(true);
            startPlayer();
            setLastPlayerRetry(now.setSeconds(now.getSeconds() + 30));

            setTimeout(function () {
                recoverError();
            }, 1000);
        } else {

            if (!getPlayer().isPlaying()) {
                if (now.getTime() <= getLastPlayerRetry()) {
                    startPlayer();

                    setTimeout(function () {
                        recoverError();
                    }, 1000);
                } else {
                    setLastPlayerRetry(null);

                    setTimeout(function () {
                        retryConnection();
                    }, 30000);
                }
            }
        }
    }
}

function showPlayerError() {
    if (getPlayer()) {
        stopPlayer(false);
    }

    if ($('#player-channel-info').length === 0) {
        $('.player-poster').append('<div id="player-channel-info" class="player-channel-info" style="display:none;"></div>');
    }

    $('#player-channel-info').text("Canal não pode ser exibido! Tentando reconectar...");
    $('#player-channel-info').show();
    hidePlayerErrors();
}

/*Custom Clappr Media Control*/
var customMediaControlTemplate = '';

class TboxMediaControl extends Clappr.MediaControl {

    constructor(options) {
        super(options);
    }

    get template() {
        return Clappr.template(
            '<div>' + getCustomMediaControl() + '</div>'
        )
    }
}

function setCustomMediaControl(remove) {
    var removingParams;
    if (remove.length <= 0) {
        removingParams = 'if(true){';
    } else {
        removingParams = 'if(true && ';
        for (var i = 0; i < remove.length; i++) {
            removingParams += "setting !== \"" + remove[i] + "\" &&"
        }
        removingParams += ' true) {'
    }

    if (remove.includes("live")) {
        addCssRule(".live-info", "display: none !important;");
    }

    addCssRule(".media-control[data-media-control] .media-control-background[data-background]", "height: 100% !important;");

    customMediaControlTemplate +=
        '<div class="media-control-background" data-background></div>' +
        '<div class="media-control-layer" data-controls>' +
        '<%  var renderBar = function(name) { %>' +
        '<div class="bar-container" data-<%= name %>>' +
        '<div class="bar-background" data-<%= name %>>' +
        '<div class="bar-fill-1" data-<%= name %>></div>' +
        '<div class="bar-fill-2" data-<%= name %>></div>' +
        '<div class="bar-hover" data-<%= name %>></div>' +
        '</div>' +
        '<div class="bar-scrubber" data-<%= name %>>' +
        '<div class="bar-scrubber-icon" data-<%= name %>></div>' +
        '</div>' +
        '</div>' +
        '<%  }; %>' +

        '<%  var renderSegmentedBar = function(name, segments) {' +
        'segments = segments || 10; %>' +
        '<div class="bar-container" data-<%= name %>>' +
        '<% for (var i = 0; i < segments; i++) { %>' +
        '<div class="segmented-bar-element" data-<%= name %>></div>' +
        '<% } %>' +
        '</div>' +
        '<% }; %>' +

        '<% var renderDrawer = function(name, renderContent) { %>' +
        '<div class="drawer-container" data-<%= name %>>' +
        '<div class="drawer-icon-container" data-<%= name %>>' +
        '<div class="drawer-icon media-control-icon" data-<%= name %>></div>' +
        '<span class="drawer-text" data-<%= name %>></span>' +
        '</div>' +
        '<% renderContent(name); %>' +
        '</div>' +
        '<% }; %>' +

        '<% var renderIndicator = function(name) { %>' +
        '<div class="media-control-indicator" data-<%= name %>></div>' +
        '<% }; %>' +

        '<% var renderButton = function(name) { %>' +
        '<button type="button" class="media-control-button media-control-icon" data-<%= name %> aria-label="<%= name %>"></button>' +
        '<% }; %>' +

        '<%  var templates = {' +
        'bar: renderBar,' +
        'segmentedBar: renderSegmentedBar,' +
        '};' +
        'var render = function(settingsList) {' +
        'settingsList.forEach(function(setting) {' +
        removingParams +
        'if(setting === "seekbar") {' +
        'renderBar(setting);' +
        '} else if (setting === "volume") {' +
        'renderDrawer(setting, settings.volumeBarTemplate ? templates[settings.volumeBarTemplate] : function(name) { return renderSegmentedBar(name); });' +
        '} else if (setting === "duration" || setting === "position") {' +
        'renderIndicator(setting);' +
        '} else {' +
        'renderButton(setting);' +
        '}' +
        '}' +
        '});' +
        '}; %>' +

        '<% if (settings.default && settings.default.length) { %>' +
        '<div class="media-control-center-panel" data-media-control>' +
        '<% render(settings.default); %>' +
        '</div>' +
        '<% } %>' +

        '<% if (settings.left && settings.left.length) { %>' +
        '<div class="media-control-left-panel" data-media-control>' +
        '<% render(settings.left); %>' +
        '</div>' +
        '<% } %>' +

        '<% if (settings.right && settings.right.length) { %>' +
        '<div class="media-control-right-panel" data-media-control>' +
        '<% render(settings.right); %>' +
        '</div>' +
        '<% } %>' +
        '</div>';
}

function getCustomMediaControl() {
    return customMediaControlTemplate;
}